# **neuralNetwork** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 神经网络项目集合
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.7-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()


### 安装
    pip install jtyoui

### 项目集合
1. [kerase项目](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/neuralNetwork/kerase)  
2. [tensorFlow项目](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/neuralNetwork/tf1)  
3. [PaddlePaddle项目](https://github.com/jtyoui/Jtyoui/tree/master/jtyoui/neuralNetwork/paddle)  

***
[1]: https://blog.jtyoui.com